@@ -21,3 +21,7 @@ pack_list = glob.glob(
 pack_str = " ".join(pack_list)
 release_id = subprocess.check_output(["lsb_release", "--id", "--short"]).decode().rstrip()
 key_file = "public_key.gpg"
+
+personal_slug = 'veltzer'
+exception = f'50{personal_slug}'
+apache_site_file = f'{personal_slug}.apt'
