@@ -1,12 +1,12 @@
 import sys
 import os
-import pickle
+import os.path
 import pathlib
 import shutil
 import logging
 
 import pylogconf.core
-from pytconf import register_endpoint, register_main, config_arg_parse_and_launch, get_free_args
+from pytconf import register_endpoint, register_main, config_arg_parse_and_launch
 
 from pydmt.configs import ConfigSudo, ConfigFlow, ConfigOutput, ConfigTarget, ConfigLogging
 from pydmt.core.pydmt import PyDMT
@@ -23,6 +23,12 @@ from pydmt.features.reqs import FeatureReqs
 from pydmt.features.make import FeatureMake
 
 
+def check_config_and_load():
+    if not os.path.isfile(".pydmt.config"):
+        print("pydmt: not a pydmt folder", file=sys.stderr)
+        sys.exit(1)
+
+
 def add_all_features(p):
     f = FeatureApt()
     f.setup(p)
@@ -76,6 +82,8 @@ def add_to_path():
     ],
 )
 def build():
+    check_config_and_load()
+
     add_to_path()
 
     pylogconf.core.setup()
@@ -100,6 +108,8 @@ def build():
     ],
 )
 def build_venv():
+    check_config_and_load()
+
     add_to_path()
 
     pylogconf.core.setup()
@@ -125,6 +135,8 @@ def build_venv():
     ],
 )
 def build_reqs():
+    check_config_and_load()
+
     add_to_path()
 
     pylogconf.core.setup()
@@ -150,6 +162,8 @@ def build_reqs():
     ],
 )
 def build_tools():
+    check_config_and_load()
+
     add_to_path()
 
     pylogconf.core.setup()
@@ -174,6 +188,8 @@ def build_tools():
     ],
 )
 def clean() -> None:
+    check_config_and_load()
+
     add_to_path()
 
     pylogconf.core.setup()
@@ -195,6 +211,8 @@ def clean() -> None:
     ],
 )
 def clean_hard() -> None:
+    check_config_and_load()
+
     logger = logging.getLogger(LOGGER_NAME)
     logger.setLevel(ConfigLogging.loglevel)
 
@@ -202,20 +220,6 @@ def clean_hard() -> None:
     check_call(["git", "clean", "-qffxd"])
 
 
-@register_endpoint(
-    description="print a pickle file for debug purposes",
-    configs=[
-    ],
-    allow_free_args=True,
-)
-def print_pickle() -> None:
-    for filename in get_free_args():
-        with open(filename, "rb") as file_handle:
-            print(f"{filename}")
-            for x, y in pickle.load(file_handle).items():
-                print(x, y)
-
-
 @register_main(
     app_name=APP_NAME,
     version=VERSION_STR,
